==> v0.5.4.tar.gz: libarea/app/Languages/ar/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => 'المزيد',
    'category'          => 'التصنيف',
    'categories'        => 'التصنيفات',
    'audits'            => 'الابلاغ',
    'soft'              => 'لين',
    'website'           => 'موقع الكتروني',
    'websites'          => 'مواقع',
    'on_website'        => 'الى الموقع الالكتروني',
    'deleted'           => 'بعيد',
    'facets'            => 'جوانب',
    'favorites'         => 'المفضلات',
    'menu'              => 'لا',
    'yes'               => 'نعم',
    'title'             => 'اسم',
    'description'       => 'الوصف',
    'catalog'           => 'تصنيف',
    'find'              => 'اعثر',
    'help'              => 'فكرة',
    'deny_replies'      => 'رفض الردود؟',
    'posted'            => 'منشور؟',
    'necessarily'       => 'مطلوب ملئه',
    'status'            => 'حالة الرابط',
    'there_program'     => 'هل هناك برنامج؟',
    'there_forum'       => 'هل لهذا الموقع منتدى؟',
    'there_portal'      => 'هذه بوابة؟',
    'there_blog'        => 'هل هذه مدونة شخصية؟',
    'there_reference'   => 'هل هذا موقع مصطحات (موسوعة)؟',
    'there_goods'       => 'هل يقدم الموقع منتجات وخدمات؟',
    'hosted_github'     => 'هل هذا البرنامج مستضاف على غيت هاب؟',
    'url_github'        => 'رابط مستودع غيت هاب',
    'related_posts'     => 'منشورات ذو صلة',
    'desc_formed'       => 'تم انشاء الوصف',
    'by_date'           => 'بحسب التاريخ',
    'top_view'          => 'بحسب التقيم',
    'new_sites'         => 'مواقع جديدة',
    'audits_view'       => 'يتطلب اخذ بعين الاعتبار',
    'deleted_view'      => 'تم ازالته',
    'my_website'        => 'مواقعي',
    'no_website'        => 'لا مواقع بعد',
    'bookmarks'         => 'مفضلاتي الخاصة بالمواقع',
    'bookmarks_view'    => 'مفضلاتي',
    'no_bookmarks'      => 'لا يوجد مفضلات',
    'answers'           => 'اجابات',
    'no_answers'        => 'لا يوجد اجابات بعد...',
    'characters'        => 'احرف',
    'remove'            => 'حذف',
    'reply'             => 'رد',
    'edit'              => 'تعديل',
    'cancel'            => 'الغاء',
    'add'               => 'اضافة',
    'markdown'          => 'الغاء التنسيق',
    'recommended'       => 'موصى به',
    'my_website_info'   => 'قائمة المواقع المضافة بواسطتي',
    'moderation'        => 'اشراف',
    'sign_in'           => 'تسجيل الدخول',
    'registration'      => 'التسجيل',
    'site_added'        => 'تم اضافة الموقع',

    'closed'            => 'مناقشة الموقع محظور. المؤلف أو فريق العمل قاموا بغلق النقاش.',

    'screenshot_time'   => 'اخذ لقطة شاشة قد يستغرق بعض الوقت.',
 
    'audits_home_title' => 'تقارير الموقع',
    'audits_home_desc'  => 'المواقع تحت المراجعة',
    'num_website'       => ['موقع', 'مواقع', 'مواقع'],
    
    'news'              => 'الاخبار و الاعلام',
    'internet'          => 'الانترنيت',
    'culture'           => 'ثقافة و فن',
    'software'          => 'برامج',
    'reference_info'    => 'معلومات و مصطلحات',
    'reference_help'    => 'موسوعات, كتب مصطلحات',
    'science'           => 'علوم و تعليم',
    'business'          => 'اعمال',
    'life'              => 'المنزل',
    'cms'               => 'ادارة محتوى',
    'life_help'         => 'اطفال, حيوانات, هوايات...',
    'security'          => 'امن...',
    'society'           => 'مجتمع و سياسة',

    'contact_information'   => 'معلومات التواصل',
    'telephone'             => 'هاتف',
    'email'                 => 'Email',
    'vk'                    => 'Vkontakte (URL)',
    'telegram'              => 'Telegram (URL)',

    'string_length'         => 'طول خطأ {name}',
    'website_correctness'   => 'العنون (الرابط) لهذا الموقع غير صحيح',
    'site_replay'           => 'موقع مماثل موجود بالفعل',

    'data_help'         => '<i class="gray-600">صيغة العنوان:</i><br> «LibArea» — community<br><br><i class="gray-600">الوصف (بدون اعلانات)):</i><br> ...ماذا يوجد بالموقع؟<i>',
    
    'add_category'      => 'اضافة تصنيف',
    'add_website'       => 'اضافة موقع',
    'edit_website'      => 'تعديل موقع',
    
    'sidebar_info'      => 'تصنيفات المواقع منظمة بحسب العناوين النمطية',
    'banner_info'       => 'تصنيفات المواقع مع التعليقات التوضيحية ولقطات الشاشة. <br> اعادة صياغة الأوجه ، البحث. الإشارات المرجعية على الموارد مع القدرة على التصويت للمواقع والبرامج والتصنيف',
    
    'main_title'        => 'قاموس الموقع',
    'main_desc'         => 'قائمة المواقع في الدليل مرتبة ترتيبًا زمنيًا. القدرة على البحث ، المرجعية ، الفرز حسب الشعبية',
    
    'deleted_title'     => 'مواقع بعيدة',
    'deleted_desc'      => '...',
    'audits_title'      => 'مراجعة الموقع',
    'audits_desc'       => '...',

    'all'               => 'الكل',
    'github'            => 'غيت هاب',
    'forum'             => 'منتديات',
    'blog'              => 'مدونات',
    'portal'            => 'بوابات',
    'reference'         => 'موسوعات',
    'goods'             => 'مواد و خدمات',

    'top_title'         => '{name} — مواقع بحسب الشعبية',
    'top_desc'          => 'القائمة المعلنة للمواقع بحسب الموضوع {description_info}',
    'all_title'         => '{name} — مواقع بحسب التاريخ, التقييم',
    'all_desc'          => 'المواقع بالترتيب الزمني في نموذج التقييم {description_info}',
];

==> v0.5.6.tar.gz: libarea/app/Languages/ar/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => 'المزيد',
    'category'          => 'التصنيف',
    'categories'        => 'التصنيفات',
    'audits'            => 'الابلاغ',
    'soft'              => 'لين',
    'website'           => 'موقع الكتروني',
    'websites'          => 'مواقع',
    'comments'          => 'تعليقات',
    'on_website'        => 'الى الموقع الالكتروني',
    'deleted'           => 'بعيد',
    'facets'            => 'جوانب',
    'favorites'         => 'المفضلات',
    'menu'              => 'لا',
    'yes'               => 'نعم',
    'title'             => 'اسم',
    'description'       => 'الوصف',
    'catalog'           => 'تصنيف',
    'find'              => 'اعثر',
    'help'              => 'فكرة',
    'deny_replies'      => 'رفض الردود؟',
    'posted'            => 'منشور؟',
    'necessarily'       => 'مطلوب ملئه',
    'status'            => 'حالة',
    'refresh'           => 'ينعش',
    'there_program'     => 'هل هناك برنامج؟',
    'there_forum'       => 'هل لهذا الموقع منتدى؟',
    'there_portal'      => 'هذه بوابة؟',
    'there_blog'        => 'هل هذه مدونة شخصية؟',
    'there_reference'   => 'هل هذا موقع مصطحات (موسوعة)؟',
    'there_goods'       => 'هل يقدم الموقع منتجات وخدمات؟',
    'hosted_github'     => 'هل هذا البرنامج مستضاف على غيت هاب؟',
    'url_github'        => 'رابط مستودع غيت هاب',
    'related_posts'     => 'منشورات ذو صلة',
    'desc_formed'       => 'تم انشاء الوصف',
    'by_date'           => 'بحسب التاريخ',
    'top'               => 'الافضل',
    'top_view'          => 'بحسب التقيم',
    'new_sites'         => 'مواقع جديدة',
    'audits_view'       => 'يتطلب اخذ بعين الاعتبار',
    'deleted_view'      => 'تم ازالته',
    'my_website'        => 'مواقعي',
    'no_website'        => 'لا مواقع بعد',
    'bookmarks'         => 'مفضلاتي الخاصة بالمواقع',
    'bookmarks_view'    => 'مفضلاتي',
    'no_bookmarks'      => 'لا يوجد مفضلات',
    'answers'           => 'اجابات',
    'no_answers'        => 'لا يوجد اجابات بعد...',
    'characters'        => 'احرف',
    'remove'            => 'حذف',
    'reply'             => 'رد',
    'edit'              => 'تعديل',
    'cancel'            => 'الغاء',
    'add'               => 'اضافة',
    'markdown'          => 'الغاء التنسيق',
    'recommended'       => 'موصى به',
    'my_website_info'   => 'قائمة المواقع المضافة بواسطتي',
    'moderation'        => 'اشراف',
    'sign_in'           => 'تسجيل الدخول',
    'registration'      => 'التسجيل',
    'site_added'        => 'تم اضافة الموقع',

    'closed'            => 'مناقشة الموقع محظور. المؤلف أو فريق العمل قاموا بغلق النقاش.',

    'screenshot_time'   => 'اخذ لقطة شاشة قد يستغرق بعض الوقت.',
 
    'audits_home_title' => 'تقارير الموقع',
    'audits_home_desc'  => 'المواقع تحت المراجعة',
    'num_website'       => ['موقع', 'مواقع', 'مواقع'],
    
    'news'              => 'الاخبار و الاعلام',
    'internet'          => 'الانترنيت',
    'culture'           => 'ثقافة و فن',
    'software'          => 'برامج',
    'reference_info'    => 'معلومات و مصطلحات',
    'reference_help'    => 'موسوعات, كتب مصطلحات',
    'science'           => 'علوم و تعليم',
    'business'          => 'اعمال',
    'life'              => 'المنزل',
    'cms'               => 'ادارة محتوى',
    'life_help'         => 'اطفال, حيوانات, هوايات...',
    'security'          => 'امن...',
    'society'           => 'مجتمع و سياسة',

    'contact_information'   => 'معلومات التواصل',
    'telephone'             => 'هاتف',
    'email'                 => 'Email',
    'vk'                    => 'Vkontakte (URL)',
    'telegram'              => 'Telegram (URL)',

    'string_length'         => 'طول خطأ {name}',
    'website_correctness'   => 'العنون (الرابط) لهذا الموقع غير صحيح',
    'site_replay'           => 'موقع مماثل موجود بالفعل',

    'data_help'         => '<i class="gray-600">صيغة العنوان:</i><br> «LibArea» — community<br><br><i class="gray-600">الوصف (بدون اعلانات)):</i><br> ...ماذا يوجد بالموقع؟<i>',
    'admin_help'         => 'قسم مغلق متاح فقط للموظفين',
    
    'add_category'      => 'اضافة تصنيف',
    'add_website'       => 'اضافة موقع',
    'edit_website'      => 'تعديل موقع',
    
    'sidebar_info'      => 'تصنيفات المواقع منظمة بحسب العناوين النمطية',
    'banner_info'       => 'تصنيفات المواقع مع التعليقات التوضيحية ولقطات الشاشة. <br> اعادة صياغة الأوجه ، البحث. الإشارات المرجعية على الموارد مع القدرة على التصويت للمواقع والبرامج والتصنيف',
    
    'main_title'        => 'قاموس الموقع',
    'main_desc'         => 'قائمة المواقع في الدليل مرتبة ترتيبًا زمنيًا. القدرة على البحث ، المرجعية ، الفرز حسب الشعبية',
    
    'deleted_title'     => 'مواقع بعيدة',
    'audits_title'      => 'مراجعة الموقع',

    'all'               => 'الكل',
    'github'            => 'غيت هاب',
    'forum'             => 'منتديات',
    'blog'              => 'مدونات',
    'portal'            => 'بوابات',
    'reference'         => 'موسوعات',
    'goods'             => 'مواد و خدمات',

    'top_title'         => '{name} — مواقع بحسب الشعبية',
    'top_desc'          => 'القائمة المعلنة للمواقع بحسب الموضوع {description_info}',
    'all_title'         => '{name} — مواقع بحسب التاريخ, التقييم',
    'all_desc'          => 'المواقع بالترتيب الزمني في نموذج التقييم {description_info}',
];
